#[non_exhaustive]pub struct ProvisioningConfig {Show 14 fields
pub name: String,
pub instances: Vec<InstanceConfig>,
pub networks: Vec<NetworkConfig>,
pub volumes: Vec<VolumeConfig>,
pub ticket_id: String,
pub handover_service_account: String,
pub email: String,
pub state: State,
pub location: String,
pub update_time: Option<Timestamp>,
pub cloud_console_uri: String,
pub vpc_sc_enabled: bool,
pub status_message: String,
pub custom_id: String,
/* private fields */
}Expand description
A provisioning configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The system-generated name of the provisioning config. This follows the UUID format.
instances: Vec<InstanceConfig>Instances to be created.
networks: Vec<NetworkConfig>Networks to be created.
volumes: Vec<VolumeConfig>Volumes to be created.
ticket_id: StringA generated ticket id to track provisioning request.
handover_service_account: StringA service account to enable customers to access instance credentials upon handover.
email: StringEmail provided to send a confirmation with provisioning config to. Deprecated in favour of email field in request messages.
state: StateOutput only. State of ProvisioningConfig.
location: StringOptional. Location name of this ProvisioningConfig. It is optional only for Intake UI transition period.
update_time: Option<Timestamp>Output only. Last update timestamp.
cloud_console_uri: StringOutput only. URI to Cloud Console UI view of this provisioning config.
vpc_sc_enabled: boolIf true, VPC SC is enabled for the cluster.
status_message: StringOptional status messages associated with the FAILED state.
custom_id: StringOptional. The user-defined identifier of the provisioning config.
Implementations
Sourceimpl ProvisioningConfig
impl ProvisioningConfig
Sourcepub fn set_instances<T, V>(self, v: T) -> Self
pub fn set_instances<T, V>(self, v: T) -> Self
Sourcepub fn set_networks<T, V>(self, v: T) -> Self
pub fn set_networks<T, V>(self, v: T) -> Self
Sourcepub fn set_volumes<T, V>(self, v: T) -> Self
pub fn set_volumes<T, V>(self, v: T) -> Self
Sourcepub fn set_ticket_id<T: Into<String>>(self, v: T) -> Self
pub fn set_ticket_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_handover_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_handover_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of handover_service_account.
Example
let x = ProvisioningConfig::new().set_handover_service_account("example");Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = ProvisioningConfig::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = ProvisioningConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = ProvisioningConfig::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_cloud_console_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_cloud_console_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of cloud_console_uri.
Example
let x = ProvisioningConfig::new().set_cloud_console_uri("example");Sourcepub fn set_vpc_sc_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_vpc_sc_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of vpc_sc_enabled.
Example
let x = ProvisioningConfig::new().set_vpc_sc_enabled(true);Sourcepub fn set_status_message<T: Into<String>>(self, v: T) -> Self
pub fn set_status_message<T: Into<String>>(self, v: T) -> Self
Sets the value of status_message.
Example
let x = ProvisioningConfig::new().set_status_message("example");Trait Implementations
Sourceimpl Clone for ProvisioningConfig
impl Clone for ProvisioningConfig
Sourcefn clone(&self) -> ProvisioningConfig
fn clone(&self) -> ProvisioningConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ProvisioningConfig
impl Debug for ProvisioningConfig
Sourceimpl Default for ProvisioningConfig
impl Default for ProvisioningConfig
Sourcefn default() -> ProvisioningConfig
fn default() -> ProvisioningConfig
Sourceimpl Message for ProvisioningConfig
impl Message for ProvisioningConfig
Sourceimpl PartialEq for ProvisioningConfig
impl PartialEq for ProvisioningConfig
impl StructuralPartialEq for ProvisioningConfig